@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::DualLife;
-$Acme::CPANAuthors::DualLife::VERSION = '0.42';
+$Acme::CPANAuthors::DualLife::VERSION = '0.44';
 #ABSTRACT: We are CPAN Authors of Dual Life core modules
 
 use strict;
@@ -9,7 +9,6 @@ use Acme::CPANAuthors::Register (
   AMBS => q[Alberto Manuel Brandao Simoes],
   AMS => q[Abhijit Menon-Sen],
   ANDK => q[Andreas J. Koenig],
-  ANDYA => q[Andy Armstrong],
   AUDREYT => q[Audrey Tang],
   BINGOS => q[Chris Williams],
   CHORNY => q[Alexandr Ciornii],
@@ -27,10 +26,12 @@ use Acme::CPANAuthors::Register (
   GAAS => q[Gisle Aas],
   GBARR => q[Graham Barr],
   HMBRAND => q[H.Merijn Brand],
+  ISHIGAKI => q[Kenichi Ishigaki],
   JDB => q[Jan Dubois],
   JDHEDDEN => q[Jerry D. Hedden],
   JESSE => q[Jesse Vincent],
   JHI => q[Jarkko Hietaniemi],
+  JKEENAN => q[James E Keenan],
   JPEACOCK => q[John Peacock],
   JSTOWE => q[Jonathan Stowe],
   JV => q[Johan Vromans],
@@ -39,9 +40,7 @@ use Acme::CPANAuthors::Register (
   LEEJO => q[Lee Johnson],
   LEONT => q[Leon Timmermans],
   LLAP => q[Leo Lapworth],
-  MAKAMAKA => q[Makamaka Hannyaharamitu],
   MALLEN => q[Mark Allen],
-  MARCGREEN => q[Marc Green],
   MAREKR => q[Marek Rouchal],
   MHX => q[Marcus Holland-Moritz],
   MJD => q[Mark Jason Dominus],
@@ -57,7 +56,6 @@ use Acme::CPANAuthors::Register (
   PJF => q[Paul Jamieson Fenwick],
   PMQS => q[Paul Marquess],
   RGARCIA => q[Rafael Garcia-Suarez],
-  RICHE => q[Richard Elberger],
   RJBS => q[Ricardo SIGNES],
   RMBARKER => q[Robin Barker],
   RRA => q[Russ Allbery],
@@ -68,12 +66,12 @@ use Acme::CPANAuthors::Register (
   SBECK => q[Sullivan Beck],
   SHAY => q[Steve Hay],
   SIMONW => q[Simon Wistow],
-  SMPETERS => q[Steve Peters],
   SMUELLER => q[Steffen Mueller],
   TJENNESS => q[Tim Jenness],
   TODDR => q[Todd Rinaldo],
   TOMHUGHES => q[Tom Hughes],
   WOLFSAGE => q[Matthew Horsfall (alh)],
+  XSAWYERX => q[Sawyer X],
   ZEFRAM => q[Andrew Main (Zefram)],
 );
 
@@ -91,7 +89,7 @@ Acme::CPANAuthors::DualLife - We are CPAN Authors of Dual Life core modules
 
 =head1 VERSION
 
-version 0.42
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -117,7 +115,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   AMBS => q[Alberto Manuel Brandao Simoes],
   AMS => q[Abhijit Menon-Sen],
   ANDK => q[Andreas J. Koenig],
-  ANDYA => q[Andy Armstrong],
   AUDREYT => q[Audrey Tang],
   BINGOS => q[Chris Williams],
   CHORNY => q[Alexandr Ciornii],
@@ -135,10 +132,12 @@ It is currently statically generated information, I hope to make it dynamic in t
   GAAS => q[Gisle Aas],
   GBARR => q[Graham Barr],
   HMBRAND => q[H.Merijn Brand],
+  ISHIGAKI => q[Kenichi Ishigaki],
   JDB => q[Jan Dubois],
   JDHEDDEN => q[Jerry D. Hedden],
   JESSE => q[Jesse Vincent],
   JHI => q[Jarkko Hietaniemi],
+  JKEENAN => q[James E Keenan],
   JPEACOCK => q[John Peacock],
   JSTOWE => q[Jonathan Stowe],
   JV => q[Johan Vromans],
@@ -147,9 +146,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   LEEJO => q[Lee Johnson],
   LEONT => q[Leon Timmermans],
   LLAP => q[Leo Lapworth],
-  MAKAMAKA => q[Makamaka Hannyaharamitu],
   MALLEN => q[Mark Allen],
-  MARCGREEN => q[Marc Green],
   MAREKR => q[Marek Rouchal],
   MHX => q[Marcus Holland-Moritz],
   MJD => q[Mark Jason Dominus],
@@ -165,7 +162,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   PJF => q[Paul Jamieson Fenwick],
   PMQS => q[Paul Marquess],
   RGARCIA => q[Rafael Garcia-Suarez],
-  RICHE => q[Richard Elberger],
   RJBS => q[Ricardo SIGNES],
   RMBARKER => q[Robin Barker],
   RRA => q[Russ Allbery],
@@ -176,12 +172,12 @@ It is currently statically generated information, I hope to make it dynamic in t
   SBECK => q[Sullivan Beck],
   SHAY => q[Steve Hay],
   SIMONW => q[Simon Wistow],
-  SMPETERS => q[Steve Peters],
   SMUELLER => q[Steffen Mueller],
   TJENNESS => q[Tim Jenness],
   TODDR => q[Todd Rinaldo],
   TOMHUGHES => q[Tom Hughes],
   WOLFSAGE => q[Matthew Horsfall (alh)],
+  XSAWYERX => q[Sawyer X],
   ZEFRAM => q[Andrew Main (Zefram)],
 
 =head1 SEE ALSO
@@ -196,7 +192,7 @@ Chris Williams
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
